@@ -205,8 +205,10 @@ open_write(int fd, int compress_level) // compress_level==-1 for the default lev
     return fp;
 }
 
+/* BGZF* */
+/* bgzf_open(const char* __restrict path, const char* __restrict mode) */
 BGZF*
-bgzf_open(const char* __restrict path, const char* __restrict mode)
+bgzf_open(const char* path, const char* mode)
 {
     BGZF* fp = NULL;
     if (strchr(mode, 'r') || strchr(mode, 'R')) { /* The reading mode is preferred. */
@@ -246,8 +248,10 @@ bgzf_open(const char* __restrict path, const char* __restrict mode)
     return fp;
 }
 
+/* BGZF* */
+/* bgzf_fdopen(int fd, const char * __restrict mode) */
 BGZF*
-bgzf_fdopen(int fd, const char * __restrict mode)
+bgzf_fdopen(int fd, const char * mode)
 {
 	if (fd == -1) return 0;
     if (mode[0] == 'r' || mode[0] == 'R') {
